class Boring < Formula
  desc "`boring` SSH tunnel manager"
  homepage "https://github.com/alebeck/boring"
  url "https://github.com/alebeck/boring/archive/refs/tags/0.8.0.tar.gz"
  sha256 "378f6bb1becb6d5a90a086306ba22a3bafa12f7f796f94e739d873d2cce41601"
  license "MIT"

  depends_on "go" => :build

  def install
    ldflags = "-s -w -X main.version=#{version}"
    system "go", "build", *std_go_args(ldflags:), "./cmd/boring"
  end

  def post_install
    quiet_system "killall", "boring"
  end

  test do
    assert_match version.to_s, shell_output(bin/"boring", 1)

    # first interaction with boring should create the user config file
    # and correctly output that no tunnels are currently configured
    test_config = testpath/".boring.toml"
    ENV["BORING_CONFIG"] = test_config
    output = shell_output("#{bin}/boring list")
    assert output.end_with?("No tunnels configured.\n")
    assert_predicate test_config, :exist?

    # now add an example tunnel and check that it is parsed correctly
    test_config.write <<~EOF, mode: "a+"
      [[tunnels]]
      name = "dev"
      local = "9000"
      remote = "localhost:9000"
      host = "dev-server"
    EOF
    output = shell_output("#{bin}/boring list")
    assert_match "dev   9000   ->  localhost:9000  dev-server", output
  end
end
